@@ -1,19 +1,21 @@
-from __future__ import unicode_literals
-
 import os
 
 from django.conf import settings
 from django.template import TemplateDoesNotExist
-from django.template.loaders import filesystem, app_directories
+from django.template.loaders import app_directories, filesystem
 
-from hamlpy import hamlpy
+from hamlpy import HAML_EXTENSIONS
+from hamlpy.compiler import Compiler
 from hamlpy.template.utils import get_django_template_loaders
 
 # Get options from Django settings
-options_dict = {}
+options = {}
 
-if hasattr(settings, 'HAMLPY_ATTR_WRAPPER'):
-    options_dict.update(attr_wrapper=settings.HAMLPY_ATTR_WRAPPER)
+if hasattr(settings, "HAMLPY_ATTR_WRAPPER"):
+    options.update(attr_wrapper=settings.HAMLPY_ATTR_WRAPPER)
+
+if hasattr(settings, "HAMLPY_DJANGO_INLINE_STYLE"):
+    options.update(django_inline_style=settings.HAMLPY_DJANGO_INLINE_STYLE)
 
 
 def get_haml_loader(loader):
@@ -23,10 +25,10 @@ def get_haml_loader(loader):
             contents = super(Loader, self).get_contents(origin)
             name, _extension = os.path.splitext(origin.template_name)
             # os.path.splitext always returns a period at the start of extension
-            extension = _extension.lstrip('.')
+            extension = _extension.lstrip(".")
 
-            if extension in hamlpy.VALID_EXTENSIONS:
-                compiler = hamlpy.Compiler(options_dict=options_dict)
+            if extension in HAML_EXTENSIONS:
+                compiler = Compiler(options=options)
                 return compiler.process(contents)
 
             return contents
@@ -35,18 +37,18 @@ def get_haml_loader(loader):
             # Django<1.9
             name, _extension = os.path.splitext(template_name)
             # os.path.splitext always returns a period at the start of extension
-            extension = _extension.lstrip('.')
+            extension = _extension.lstrip(".")
 
-            if extension in hamlpy.VALID_EXTENSIONS:
+            if extension in HAML_EXTENSIONS:
                 try:
                     haml_source, template_path = super(Loader, self).load_template_source(
                         self._generate_template_name(name, extension), *args, **kwargs
                     )
-                except TemplateDoesNotExist:
+                except TemplateDoesNotExist:  # pragma: no cover
                     pass
                 else:
-                    hamlParser = hamlpy.Compiler(options_dict=options_dict)
-                    html = hamlParser.process(haml_source)
+                    compiler = Compiler(options=options)
+                    html = compiler.process(haml_source)
 
                     return html, template_path
 
@@ -54,7 +56,8 @@ def get_haml_loader(loader):
 
         load_template_source.is_usable = True
 
-        def _generate_template_name(self, name, extension="hamlpy"):
+        @staticmethod
+        def _generate_template_name(name, extension="hamlpy"):
             return "%s.%s" % (name, extension)
 
     return Loader
